pub struct FlyingCameraController {Show 21 fields
pub yaw: InheritableVariable<f32>,
pub pitch: InheritableVariable<f32>,
pub speed: InheritableVariable<f32>,
pub sensitivity: InheritableVariable<f32>,
pub pitch_limit: InheritableVariable<Range<f32>>,
pub move_forward_key: InheritableVariable<KeyBinding>,
pub move_backward_key: InheritableVariable<KeyBinding>,
pub move_left_key: InheritableVariable<KeyBinding>,
pub move_right_key: InheritableVariable<KeyBinding>,
pub acceleration_curve: InheritableVariable<Curve>,
pub deceleration_curve: InheritableVariable<Curve>,
pub acceleration_time: InheritableVariable<f32>,
pub deceleration_time: InheritableVariable<f32>,
pub reactivity: InheritableVariable<f32>,
pub velocity: InheritableVariable<Vector3<f32>>,
pub target_velocity: InheritableVariable<Vector3<f32>>,
pub acceleration_coeff: f32,
pub move_forward: bool,
pub move_backward: bool,
pub move_left: bool,
pub move_right: bool,
}Expand description
Flying camera controller script is used to create flying cameras, that can be rotated via mouse and moved via keyboard keys. Use it, if you need to create a sort of “spectator” camera. To use it, all you need to do is to assign it to your camera node (or one if its parent nodes).
Fields
yaw: InheritableVariable<f32>Current yaw of the camera pivot (in radians).
pitch: InheritableVariable<f32>Current pitch of the camera (in radians).
speed: InheritableVariable<f32>Maximum speed of the camera.
sensitivity: InheritableVariable<f32>Mouse sensitivity.
pitch_limit: InheritableVariable<Range<f32>>Angular limit of the pitch of the camera (in radians).
move_forward_key: InheritableVariable<KeyBinding>A key, that corresponds to forward movement.
move_backward_key: InheritableVariable<KeyBinding>A key, that corresponds to backward movement.
move_left_key: InheritableVariable<KeyBinding>A key, that corresponds to left movement.
move_right_key: InheritableVariable<KeyBinding>A key, that corresponds to right movement.
acceleration_curve: InheritableVariable<Curve>A curve, that defines a how speed of the camera changes when accelerating to the max speed.
deceleration_curve: InheritableVariable<Curve>A curve, that defines a how speed of the camera changes when decelerating to the zero speed.
acceleration_time: InheritableVariable<f32>Amount of time (in seconds) during which the camera will accelerate to the max speed.
deceleration_time: InheritableVariable<f32>Amount of time (in seconds) during which the camera will decelerate to the zero speed.
reactivity: InheritableVariable<f32>A coefficient, that defines how fast the camera will respond to pressed keys.
velocity: InheritableVariable<Vector3<f32>>target_velocity: InheritableVariable<Vector3<f32>>acceleration_coeff: f32move_forward: boolmove_backward: boolmove_left: boolmove_right: boolImplementations
Sourceimpl FlyingCameraController
impl FlyingCameraController
pub const YAW: &'static str = "yaw"
pub const PITCH: &'static str = "pitch"
pub const SPEED: &'static str = "speed"
pub const SENSITIVITY: &'static str = "sensitivity"
pub const PITCH_LIMIT: &'static str = "pitch_limit"
pub const MOVE_FORWARD_KEY: &'static str = "move_forward_key"
pub const MOVE_BACKWARD_KEY: &'static str = "move_backward_key"
pub const MOVE_LEFT_KEY: &'static str = "move_left_key"
pub const MOVE_RIGHT_KEY: &'static str = "move_right_key"
pub const ACCELERATION_CURVE: &'static str = "acceleration_curve"
pub const DECELERATION_CURVE: &'static str = "deceleration_curve"
pub const ACCELERATION_TIME: &'static str = "acceleration_time"
pub const DECELERATION_TIME: &'static str = "deceleration_time"
pub const REACTIVITY: &'static str = "reactivity"